# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class DetectionQuality(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'non_compliant': '[FaceQualityConfigName]',
        'details_groups': '[QualityDetailsGroups]',
        'details': '[QualityDetail]',
        'score': 'float',
        'timer': 'float',
    }

    attribute_map = {
        'non_compliant': 'nonCompliant',
        'details_groups': 'detailsGroups',
        'details': 'details',
        'score': 'score',
        'timer': 'timer',
    }

    def __init__(self, non_compliant=None, details_groups=None, details=None, score=None, timer=None, local_vars_configuration=None):  # noqa: E501
        """DetectionQuality - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._non_compliant = None
        self._details_groups = None
        self._details = None
        self._score = None
        self._timer = None
        self.discriminator = None

        if non_compliant is not None:
            self.non_compliant = non_compliant
        if details_groups is not None:
            self.details_groups = details_groups
        if details is not None:
            self.details = details
        if score is not None:
            self.score = score
        if timer is not None:
            self.timer = timer

    @property
    def non_compliant(self):
        """Gets the non_compliant of this DetectionQuality.  # noqa: E501

        The array of all the non-compliant assessment characteristics.  # noqa: E501

        :return: The non_compliant of this DetectionQuality.  # noqa: E501
        :rtype: [FaceQualityConfigName]
        """
        return self._non_compliant

    @non_compliant.setter
    def non_compliant(self, non_compliant):
        """Sets the non_compliant of this DetectionQuality.

        The array of all the non-compliant assessment characteristics.  # noqa: E501

        :param non_compliant: The non_compliant of this DetectionQuality.  # noqa: E501
        :type non_compliant: [FaceQualityConfigName]
        """

        self._non_compliant = non_compliant

    @property
    def details_groups(self):
        """Gets the details_groups of this DetectionQuality.  # noqa: E501

        The array of the assessment results for each group of characteristics.  # noqa: E501

        :return: The details_groups of this DetectionQuality.  # noqa: E501
        :rtype: [QualityDetailsGroups]
        """
        return self._details_groups

    @details_groups.setter
    def details_groups(self, details_groups):
        """Sets the details_groups of this DetectionQuality.

        The array of the assessment results for each group of characteristics.  # noqa: E501

        :param details_groups: The details_groups of this DetectionQuality.  # noqa: E501
        :type details_groups: [QualityDetailsGroups]
        """

        self._details_groups = details_groups

    @property
    def details(self):
        """Gets the details of this DetectionQuality.  # noqa: E501

        The array of the assessment characteristics that were set in the request.  # noqa: E501

        :return: The details of this DetectionQuality.  # noqa: E501
        :rtype: [QualityDetail]
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this DetectionQuality.

        The array of the assessment characteristics that were set in the request.  # noqa: E501

        :param details: The details of this DetectionQuality.  # noqa: E501
        :type details: [QualityDetail]
        """

        self._details = details

    @property
    def score(self):
        """Gets the score of this DetectionQuality.  # noqa: E501

        Returns the estimated portrait quality assessment result, a number from 0 to 1, where 1 is for absolute compliance.  # noqa: E501

        :return: The score of this DetectionQuality.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this DetectionQuality.

        Returns the estimated portrait quality assessment result, a number from 0 to 1, where 1 is for absolute compliance.  # noqa: E501

        :param score: The score of this DetectionQuality.  # noqa: E501
        :type score: float
        """

        self._score = score

    @property
    def timer(self):
        """Gets the timer of this DetectionQuality.  # noqa: E501

        The total time the quality assessment has taken.  # noqa: E501

        :return: The timer of this DetectionQuality.  # noqa: E501
        :rtype: float
        """
        return self._timer

    @timer.setter
    def timer(self, timer):
        """Sets the timer of this DetectionQuality.

        The total time the quality assessment has taken.  # noqa: E501

        :param timer: The timer of this DetectionQuality.  # noqa: E501
        :type timer: float
        """

        self._timer = timer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectionQuality):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DetectionQuality):
            return True

        return self.to_dict() != other.to_dict()



from regula.facesdk.webclient.ext.api import MatchingApi, FaceSdk
from regula.facesdk.webclient.ext.common import Base64String
from regula.facesdk.webclient.ext.models import MatchRequest
from regula.facesdk.webclient.ext.models import MatchImage
from regula.facesdk.webclient.ext.models import DetectRequest



# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class FaceSDKResultCode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    ""
    FACER_OK = int(0)

    ""
    FACER_NO_LICENSE = int(200)

    ""
    FACER_IS_NOT_INITIALIZED = int(201)

    ""
    FACER_COMMAND_IS_NOT_SUPPORTED = int(202)

    ""
    FACER_COMMAND_PARAMS_READ_ERROR = int(203)

    ""
    FACER_SEARCHER_INDEX_FILE_NOT_EXIST = int(204)

    ""
    FACER_SEARCHER_INDEX_FILE_READ_ERROR = int(205)

    ""
    FACER_SEARCHER_INDEX_FILE_DECRYPTION_ERROR = int(206)

    ""
    FACER_SEARCHER_INDEX_LOAD_ERROR = int(207)

    ""
    FACER_SEARCHER_WRONG_DESCRIPTOR_VERSION = int(208)

    ""
    FACER_SEARCHER_INDEX_FILE_ENCRYPTION_ERROR = int(209)

    ""
    FACER_SEARCHER_INDEX_FILE_SAVE_ERROR = int(210)

    ""
    FACER_SEARCHER_IMAGE_DECODE_ERROR = int(211)

    ""
    FACER_SEARCHER_ID_EXISTS_IN_INDEX = int(212)

    ""
    FACER_SEARCHER_ID_NOT_IN_INDEX = int(213)

    ""
    FACER_SEARCHER_NO_FACES = int(214)

    ""
    FACER_SEARCHER_DESCRIPTOR_EXTRACTOR_ERROR = int(215)

    ""
    FACER_SEARCHER_METADATA_READ_ERROR = int(216)

    ""
    FACER_SEARCHER_NO_SEARCH_LICENSE = int(217)

    ""
    FACER_SEARCHER_DESCRIPTOR_DECODE_ERROR = int(218)

    ""
    FACER_SEARCHER_DESCRIPTOR_WRONG_SIZE = int(219)

    ""
    FACER_SEARCHER_ZIP_IMAGE_READ_ERROR = int(220)

    ""
    FACER_SEARCHER_ZIP_META_READ_ERROR = int(221)

    ""
    FACER_SEARCHER_SIMILAR_PHOTOS_EXIST = int(222)

    ""
    FACER_SEARCHER_PERSON_ZIP_READ_ERROR = int(223)

    ""
    FACER_LESS_THAN_TWO_IMAGES_IN_REQUEST = int(224)

    ""
    FACER_SEARCHER_WRONG_ID = int(225)

    ""
    FACER_SEARCHER_ID_EXISTS_IN_DELETED = int(226)

    ""
    FACER_VIDEO_DECODE_ERROR = int(227)

    ""
    FACER_NOT_ENOUGH_FRAMES = int(228)

    ""
    FACER_OUTPUT_IS_NOT_DEFINED = int(229)

    allowable_values = [FACER_OK, FACER_NO_LICENSE, FACER_IS_NOT_INITIALIZED, FACER_COMMAND_IS_NOT_SUPPORTED, FACER_COMMAND_PARAMS_READ_ERROR, FACER_SEARCHER_INDEX_FILE_NOT_EXIST, FACER_SEARCHER_INDEX_FILE_READ_ERROR, FACER_SEARCHER_INDEX_FILE_DECRYPTION_ERROR, FACER_SEARCHER_INDEX_LOAD_ERROR, FACER_SEARCHER_WRONG_DESCRIPTOR_VERSION, FACER_SEARCHER_INDEX_FILE_ENCRYPTION_ERROR, FACER_SEARCHER_INDEX_FILE_SAVE_ERROR, FACER_SEARCHER_IMAGE_DECODE_ERROR, FACER_SEARCHER_ID_EXISTS_IN_INDEX, FACER_SEARCHER_ID_NOT_IN_INDEX, FACER_SEARCHER_NO_FACES, FACER_SEARCHER_DESCRIPTOR_EXTRACTOR_ERROR, FACER_SEARCHER_METADATA_READ_ERROR, FACER_SEARCHER_NO_SEARCH_LICENSE, FACER_SEARCHER_DESCRIPTOR_DECODE_ERROR, FACER_SEARCHER_DESCRIPTOR_WRONG_SIZE, FACER_SEARCHER_ZIP_IMAGE_READ_ERROR, FACER_SEARCHER_ZIP_META_READ_ERROR, FACER_SEARCHER_SIMILAR_PHOTOS_EXIST, FACER_SEARCHER_PERSON_ZIP_READ_ERROR, FACER_LESS_THAN_TWO_IMAGES_IN_REQUEST, FACER_SEARCHER_WRONG_ID, FACER_SEARCHER_ID_EXISTS_IN_DELETED, FACER_VIDEO_DECODE_ERROR, FACER_NOT_ENOUGH_FRAMES, FACER_OUTPUT_IS_NOT_DEFINED]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """FaceSDKResultCode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FaceSDKResultCode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FaceSDKResultCode):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class DetectionFace(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'face_index': 'float',
        'landmarks': '[[float]]',
        'roi': 'FaceRectangular',
        'thumbnail': 'str',
    }

    attribute_map = {
        'face_index': 'faceIndex',
        'landmarks': 'landmarks',
        'roi': 'roi',
        'thumbnail': 'thumbnail',
    }

    def __init__(self, face_index=None, landmarks=None, roi=None, thumbnail=None, local_vars_configuration=None):  # noqa: E501
        """DetectionFace - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._face_index = None
        self._landmarks = None
        self._roi = None
        self._thumbnail = None
        self.discriminator = None

        if face_index is not None:
            self.face_index = face_index
        if landmarks is not None:
            self.landmarks = landmarks
        if roi is not None:
            self.roi = roi
        if thumbnail is not None:
            self.thumbnail = thumbnail

    @property
    def face_index(self):
        """Gets the face_index of this DetectionFace.  # noqa: E501

        Faces index used to identify faces in scope of one photo.  # noqa: E501

        :return: The face_index of this DetectionFace.  # noqa: E501
        :rtype: float
        """
        return self._face_index

    @face_index.setter
    def face_index(self, face_index):
        """Sets the face_index of this DetectionFace.

        Faces index used to identify faces in scope of one photo.  # noqa: E501

        :param face_index: The face_index of this DetectionFace.  # noqa: E501
        :type face_index: float
        """

        self._face_index = face_index

    @property
    def landmarks(self):
        """Gets the landmarks of this DetectionFace.  # noqa: E501

        Absolute coordinates (x,y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :return: The landmarks of this DetectionFace.  # noqa: E501
        :rtype: [[float]]
        """
        return self._landmarks

    @landmarks.setter
    def landmarks(self, landmarks):
        """Sets the landmarks of this DetectionFace.

        Absolute coordinates (x,y) of five points of each detected face: left eye, right eye, nose, left point of lips, right point of lips.  # noqa: E501

        :param landmarks: The landmarks of this DetectionFace.  # noqa: E501
        :type landmarks: [[float]]
        """

        self._landmarks = landmarks

    @property
    def roi(self):
        """Gets the roi of this DetectionFace.  # noqa: E501


        :return: The roi of this DetectionFace.  # noqa: E501
        :rtype: FaceRectangular
        """
        return self._roi

    @roi.setter
    def roi(self, roi):
        """Sets the roi of this DetectionFace.


        :param roi: The roi of this DetectionFace.  # noqa: E501
        :type roi: FaceRectangular
        """

        self._roi = roi

    @property
    def thumbnail(self):
        """Gets the thumbnail of this DetectionFace.  # noqa: E501

        Base64 of the cropped portrait.  # noqa: E501

        :return: The thumbnail of this DetectionFace.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this DetectionFace.

        Base64 of the cropped portrait.  # noqa: E501

        :param thumbnail: The thumbnail of this DetectionFace.  # noqa: E501
        :type thumbnail: str
        """

        self._thumbnail = thumbnail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetectionFace):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DetectionFace):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
import os

from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="regula.facesdk.webclient",
    version=os.getenv("PACKAGE_VERSION_TO_PUBLISH", "unknown"),
    python_requires=">=3.5",
    description="Regula's FaceSDK web python client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Regula Forensics, Inc.",
    author_email="support@regulaforensics.com",
    url="https://mobile.regulaforensics.com",
    keywords=["face recognition", "facesdk", "regulaforensics", "regula",],
    install_requires=['certifi==2022.6.15.1', 'future==0.18.2', 'python-dateutil==2.8.2', 'six==1.16.0', 'urllib3==1.26.12'





],
    packages=find_packages(exclude=["test", "tests", "example"]),
    include_package_data=True,
)


# coding: utf-8

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from regula.facesdk.webclient.gen.configuration import Configuration


class FaceQualityConfigName(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    ""
    ART_FACE = "ArtFace"

    ""
    IMAGE_WIDTH = "ImageWidth"

    ""
    IMAGE_HEIGHT = "ImageHeight"

    ""
    IMAGE_WIDTH_TO_HEIGHT = "ImageWidthToHeight"

    ""
    IMAGE_CHANNELS_NUMBER = "ImageChannelsNumber"

    ""
    PADDING_RATIO = "PaddingRatio"

    ""
    FACE_MID_POINT_HORIZONTAL_POSITION = "FaceMidPointHorizontalPosition"

    ""
    FACE_MID_POINT_VERTICAL_POSITION = "FaceMidPointVerticalPosition"

    ""
    HEAD_WIDTH_RATIO = "HeadWidthRatio"

    ""
    HEAD_HEIGHT_RATIO = "HeadHeightRatio"

    ""
    EYES_DISTANCE = "EyesDistance"

    ""
    YAW = "Yaw"

    ""
    PITCH = "Pitch"

    ""
    ROLL = "Roll"

    ""
    BLUR_LEVEL = "BlurLevel"

    ""
    NOISE_LEVEL = "NoiseLevel"

    ""
    EYE_RIGHT_CLOSED = "EyeRightClosed"

    ""
    EYE_LEFT_CLOSED = "EyeLeftClosed"

    ""
    EYE_RIGHT_OCCLUDED = "EyeRightOccluded"

    ""
    EYE_LEFT_OCCLUDED = "EyeLeftOccluded"

    ""
    EYES_RED = "EyesRed"

    ""
    EYE_RIGHT_COVERED_WITH_HAIR = "EyeRightCoveredWithHair"

    ""
    EYE_LEFT_COVERED_WITH_HAIR = "EyeLeftCoveredWithHair"

    ""
    OFF_GAZE = "OffGaze"

    ""
    FACE_DYNAMIC_RANGE = "FaceDynamicRange"

    ""
    UNNATURAL_SKIN_TONE = "UnnaturalSkinTone"

    ""
    TOO_DARK = "TooDark"

    ""
    TOO_LIGHT = "TooLight"

    ""
    FACE_GLARE = "FaceGlare"

    ""
    SHADOWS_ON_FACE = "ShadowsOnFace"

    ""
    DARK_GLASSES = "DarkGlasses"

    ""
    REFLECTION_ON_GLASSES = "ReflectionOnGlasses"

    ""
    FRAMES_TOO_HEAVY = "FramesTooHeavy"

    ""
    FACE_OCCLUDED = "FaceOccluded"

    ""
    HEAD_COVERING = "HeadCovering"

    ""
    BACKGROUND_UNIFORMITY = "BackgroundUniformity"

    ""
    SHADOWS_ON_BACKGROUND = "ShadowsOnBackground"

    ""
    OTHER_FACES = "OtherFaces"

    ""
    SHOULDERS_POSE = "ShouldersPose"

    ""
    EXPRESSION_LEVEL = "ExpressionLevel"

    ""
    MOUTH_OPEN = "MouthOpen"

    ""
    FOREHEAD_COVERING = "ForeheadCovering"

    ""
    SMILE = "Smile"

    ""
    STRONG_MAKEUP = "StrongMakeup"

    ""
    HEADPHONES = "Headphones"

    ""
    MEDICAL_MASK = "MedicalMask"

    ""
    BACKGROUND_COLOR_MATCH = "BackgroundColorMatch"

    allowable_values = [ART_FACE, IMAGE_WIDTH, IMAGE_HEIGHT, IMAGE_WIDTH_TO_HEIGHT, IMAGE_CHANNELS_NUMBER, PADDING_RATIO, FACE_MID_POINT_HORIZONTAL_POSITION, FACE_MID_POINT_VERTICAL_POSITION, HEAD_WIDTH_RATIO, HEAD_HEIGHT_RATIO, EYES_DISTANCE, YAW, PITCH, ROLL, BLUR_LEVEL, NOISE_LEVEL, EYE_RIGHT_CLOSED, EYE_LEFT_CLOSED, EYE_RIGHT_OCCLUDED, EYE_LEFT_OCCLUDED, EYES_RED, EYE_RIGHT_COVERED_WITH_HAIR, EYE_LEFT_COVERED_WITH_HAIR, OFF_GAZE, FACE_DYNAMIC_RANGE, UNNATURAL_SKIN_TONE, TOO_DARK, TOO_LIGHT, FACE_GLARE, SHADOWS_ON_FACE, DARK_GLASSES, REFLECTION_ON_GLASSES, FRAMES_TOO_HEAVY, FACE_OCCLUDED, HEAD_COVERING, BACKGROUND_UNIFORMITY, SHADOWS_ON_BACKGROUND, OTHER_FACES, SHOULDERS_POSE, EXPRESSION_LEVEL, MOUTH_OPEN, FOREHEAD_COVERING, SMILE, STRONG_MAKEUP, HEADPHONES, MEDICAL_MASK, BACKGROUND_COLOR_MATCH]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """FaceQualityConfigName - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FaceQualityConfigName):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FaceQualityConfigName):
            return True

        return self.to_dict() != other.to_dict()



# flake8: noqa

"""
    Regula FaceSDK Web API

    Regula FaceSDK Web API # Clients * [JavaScript](https://github.com/regulaforensics/FaceSDK-web-js-client) client for the browser and node.js based on axios * [Java](https://github.com/regulaforensics/FaceSDK-web-java-client) client compatible with jvm and android * [Python](https://github.com/regulaforensics/FaceSDK-web-python-client) 3.5+ client * [C#](https://github.com/regulaforensics/FaceSDK-web-csharp-client) client for .NET & .NET Core   # noqa: E501

    The version of the OpenAPI document: 4.1.3
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from regula.facesdk.webclient.gen.api_client import ApiClient

# import Configuration
from regula.facesdk.webclient.gen.configuration import Configuration

# import exceptions
from regula.facesdk.webclient.gen.exceptions import OpenApiException
from regula.facesdk.webclient.gen.exceptions import ApiAttributeError
from regula.facesdk.webclient.gen.exceptions import ApiTypeError
from regula.facesdk.webclient.gen.exceptions import ApiValueError
from regula.facesdk.webclient.gen.exceptions import ApiKeyError
from regula.facesdk.webclient.gen.exceptions import ApiException



from regula.facesdk.webclient.gen import ApiClient
from regula.facesdk.webclient.gen.api.group_api import GroupApi as GenGroupApi
from regula.facesdk.webclient.gen.model.group import Group
from regula.facesdk.webclient.gen.model.group_page import GroupPage
from regula.facesdk.webclient.gen.model.group_to_create import GroupToCreate
from regula.facesdk.webclient.gen.model.persons_page import PersonsPage
from regula.facesdk.webclient.gen.model.update_group import UpdateGroup


class GroupApi(GenGroupApi):
    def __init__(self, api_client: ApiClient):
        super().__init__(api_client)

    def create_group(self, group_name: str, metadata=None, **kwargs) -> Group:
        if metadata is None:
            metadata = {}
        group_to_create = GroupToCreate(group_name, metadata)
        return super().create_group(group_to_create, **kwargs)

    def delete_group(self, group_id: int, **kwargs) -> None:
        return super().delete_group(group_id, **kwargs)

    def get_all_groups(self, page: int, size: int, **kwargs) -> GroupPage:
        return super().get_all_groups(page, size, **kwargs)

    def get_all_persons_by_group_id(self, page: int, size: int, group_id: int, **kwargs) -> PersonsPage:
        return super().get_all_persons_by_group_id(page, size, group_id, **kwargs)

    def get_group(self, group_id: int, **kwargs) -> Group:
        return super().get_group(group_id, **kwargs)

    def update_group(self, group_id: int, group_to_create: GroupToCreate, **kwargs) -> None:
        return super().update_group(group_id, group_to_create, **kwargs)

    def update_persons_in_group(self, group_id: int, update_group: UpdateGroup, **kwargs) -> None:
        return super().update_persons_in_group(group_id, update_group, **kwargs)
